@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2021 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2025 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -66,6 +66,7 @@ namespace rocalution
         this->Clear();
     }
 
+    // LCOV_EXCL_START
     template <class OperatorType, class VectorType, typename ValueType>
     void FGMRES<OperatorType, VectorType, ValueType>::Print(void) const
     {
@@ -106,6 +107,7 @@ namespace rocalution
             LOG_INFO("FGMRES(" << this->size_basis_ << ") ends");
         }
     }
+    // LCOV_EXCL_STOP
 
     template <class OperatorType, class VectorType, typename ValueType>
     void FGMRES<OperatorType, VectorType, ValueType>::Build(void)
@@ -246,8 +248,6 @@ namespace rocalution
                 {
                     this->z_[i]->MoveToHost();
                 }
-
-                this->precond_->MoveToHost();
             }
         }
     }
@@ -270,7 +270,6 @@ namespace rocalution
                 {
                     this->z_[i]->MoveToAccelerator();
                 }
-                this->precond_->MoveToAccelerator();
             }
         }
     }
