@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights Reserved.
+ * Copyright (C) 2018-2025 Advanced Micro Devices, Inc. All rights Reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -92,6 +92,7 @@ namespace rocalution
         this->levels_ = levels;
     }
 
+    // LCOV_EXCL_START
     template <class OperatorType, class VectorType, typename ValueType>
     void BaseMultiGrid<OperatorType, VectorType, ValueType>::SetPreconditioner(
         Solver<OperatorType, VectorType, ValueType>& precond)
@@ -100,6 +101,7 @@ namespace rocalution
                  "levels? use SetSmootherLevel() instead of SetPreconditioner!");
         FATAL_ERROR(__FILE__, __LINE__);
     }
+    // LCOV_EXCL_STOP
 
     template <class OperatorType, class VectorType, typename ValueType>
     void BaseMultiGrid<OperatorType, VectorType, ValueType>::SetSmoother(
@@ -192,6 +194,7 @@ namespace rocalution
         this->kcycle_full_ = kcycle_full;
     }
 
+    // LCOV_EXCL_START
     template <class OperatorType, class VectorType, typename ValueType>
     void BaseMultiGrid<OperatorType, VectorType, ValueType>::Print(void) const
     {
@@ -214,6 +217,7 @@ namespace rocalution
     {
         LOG_INFO("MultiGrid ends");
     }
+    // LCOV_EXCL_STOP
 
     template <class OperatorType, class VectorType, typename ValueType>
     void BaseMultiGrid<OperatorType, VectorType, ValueType>::Initialize(void)
@@ -470,11 +474,6 @@ namespace rocalution
                     this->q_level_[i]->MoveToHost();
                 }
             }
-
-            if(this->precond_ != NULL)
-            {
-                this->precond_->MoveToHost();
-            }
         }
     }
 
@@ -548,11 +547,6 @@ namespace rocalution
                     }
                 }
             }
-
-            if(this->precond_ != NULL)
-            {
-                this->precond_->MoveToAccelerator();
-            }
         }
     }
 
@@ -833,6 +827,7 @@ namespace rocalution
             this->Kcycle_(*rc, xc);
             break;
 
+        // LCOV_EXCL_START
         // F-cycle
         case 3:
             this->Fcycle_(*rc, xc);
@@ -841,6 +836,7 @@ namespace rocalution
         default:
             FATAL_ERROR(__FILE__, __LINE__);
             break;
+            // LCOV_EXCL_STOP
         }
 
         --this->current_level_;
@@ -926,6 +922,7 @@ namespace rocalution
         }
     }
 
+    // LCOV_EXCL_START
     template <class OperatorType, class VectorType, typename ValueType>
     void BaseMultiGrid<OperatorType, VectorType, ValueType>::Fcycle_(const VectorType& rhs,
                                                                      VectorType*       x)
@@ -933,6 +930,7 @@ namespace rocalution
         LOG_INFO("BaseMultiGrid:Fcycle_() not implemented yet");
         FATAL_ERROR(__FILE__, __LINE__);
     }
+    // LCOV_EXCL_STOP
 
     template <class OperatorType, class VectorType, typename ValueType>
     void BaseMultiGrid<OperatorType, VectorType, ValueType>::Kcycle_(const VectorType& rhs,
@@ -1009,6 +1007,7 @@ namespace rocalution
         }
     }
 
+    // LCOV_EXCL_START
     // do nothing
     template <class OperatorType, class VectorType, typename ValueType>
     void BaseMultiGrid<OperatorType, VectorType, ValueType>::SolveNonPrecond_(const VectorType& rhs,
@@ -1030,6 +1029,7 @@ namespace rocalution
             "you are calling it ...");
         FATAL_ERROR(__FILE__, __LINE__);
     }
+    // LCOV_EXCL_STOP
 
     template class BaseMultiGrid<LocalMatrix<double>, LocalVector<double>, double>;
     template class BaseMultiGrid<LocalMatrix<float>, LocalVector<float>, float>;
